/udp — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /udp

Contents

- /udp
  - POST /udp
    - Response status codes
    - Sample session

## POST /udp

Allocate an UDP port on the server

### Response status codes

- 201: UDP port allocated

### Sample session

    curl -i -X POST 'http://localhost:8000/udp' -d '{}'

    POST /udp HTTP/1.1
    {}

    HTTP/1.1 201
    CONNECTION: keep-alive
    CONTENT-LENGTH: 25
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /udp

    {
        "udp_port": 10000
    }

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »